<?php
/**
 * zenether functions and definitions
 *
 * Set up the theme and provides some helper functions, which are used in the
 * theme as custom template tags. Others are attached to action and filter
 * hooks in WordPress to change core functionality.
 *
 * When using a child theme you can override certain functions (those wrapped
 * in a function_exists() call) by defining them first in your child theme's
 * functions.php file. The child theme's functions.php file is included before
 * the parent theme's file, so the child theme functions would be used.
 *
 * @link https://codex.wordpress.org/Theme_Development
 * @link https://codex.wordpress.org/Child_Themes
 *
 * Functions that are not pluggable (not wrapped in function_exists()) are
 * instead attached to a filter or action hook.
 *
 * For more information on hooks, actions, and filters,
 * {@link https://codex.wordpress.org/Plugin_API}
 */

/**
 * Set a constant that holds the theme's minimum supported PHP version.
 */
define( 'ZENETHER_MIN_PHP_VERSION', '5.6' );

/**
 * Immediately after theme switch is fired we we want to check php version and
 * revert to previously active theme if version is below our minimum.
 */
add_action( 'after_switch_theme', 'zenether_test_for_min_php' );

/**
 * Switches back to the previous theme if the minimum PHP version is not met.
 */
function zenether_test_for_min_php() {

	// Compare versions.
	if ( version_compare( PHP_VERSION, ZENETHER_MIN_PHP_VERSION, '<' ) ) {
		// Site doesn't meet themes min php requirements, add notice...
		add_action( 'admin_notices', 'zenether_min_php_not_met_notice' );
		// ... and switch back to previous theme.
		switch_theme( get_option( 'theme_switched' ) );
		return false;

	};
}

if ( ! function_exists( 'wp_body_open' ) ) {
        function wp_body_open() {
                do_action( 'wp_body_open' );
        }
}

/**
 * An error notice that can be displayed if the Minimum PHP version is not met.
 */
function zenether_min_php_not_met_notice() {
	?>
	<div class="notice notice-error is_dismissable">
		<p>
			<?php esc_html_e( 'You need to update your PHP version to run this theme.', 'zenether' ); ?> <br />
			<?php
			printf(
				/* translators: 1 is the current PHP version string, 2 is the minmum supported php version string of the theme */
				esc_html__( 'Actual version is: %1$s, required version is: %2$s.', 'zenether' ),
				PHP_VERSION,
				ZENETHER_MIN_PHP_VERSION
			); // phpcs: XSS ok.
			?>
		</p>
	</div>
	<?php
}


if ( ! function_exists( 'zenether_setup' ) ) :
	/**
	 * zenether setup.
	 *
	 * Set up theme defaults and registers support for various WordPress features.
	 *
	 * Note that this function is hooked into the after_setup_theme hook, which
	 * runs before the init hook. The init hook is too late for some features, such
	 * as indicating support post thumbnails.
	 *
	 */
	function zenether_setup() {

		/*
		 * Make theme available for translation.
		 *
		 * Translations can be filed in the /languages/ directory
		 *
		 * If you're building a theme based on zenether, use a find and replace
		 * to change 'zenether' to the name of your theme in all the template files.
		 */
		load_theme_textdomain( 'zenether', get_template_directory() . '/languages' );

		// Add default posts and comments RSS feed links to head.
		add_theme_support( 'automatic-feed-links' );

		/*
		 * Let WordPress manage the document title.
		 * By adding theme support, we declare that this theme does not use a
		 * hard-coded <title> tag in the document head, and expect WordPress to
		 * provide it for us.
		 */
		add_theme_support( 'title-tag' );

		/*
		 * Enable support for Post Thumbnails on posts and pages.
		 *
		 * @link https://developer.wordpress.org/themes/functionality/featured-images-post-thumbnails/
		 */
		add_theme_support( 'post-thumbnails' );

		/*
		 * Add WooCommerce Support
		 */
		add_theme_support( 'woocommerce' );

		/*
		 * Switch default core markup for search form, comment form, and comments
		 * to output valid HTML5.
		 */
		add_theme_support( 'html5', array(
			'comment-form',
			'comment-list',
			'gallery',
			'caption',
		) );

		// Add support for Block Styles.
		add_theme_support( 'wp-block-styles' );

		add_theme_support( 'editor-styles' );

		/*
		 * This theme styles the visual editor to resemble the theme style,
		 * specifically font, colors, and column width.
	 	 */
		add_editor_style( array( 'css/editor-style.css', 
								 get_template_directory_uri() . '/css/font-awesome.css',
								 zenether_fonts_url()
						  ) );

		/*
		 * Set Custom Background
		 */				 
		add_theme_support( 'custom-background', array ('default-color'  => '#f1f1f1') );

		// Set the default content width.
		$GLOBALS['content_width'] = 900;

		// This theme uses wp_nav_menu() in header menu
		register_nav_menus( array(
			'primary'   => __( 'Primary Menu', 'zenether' ),
			'footer'    => __( 'Footer Menu', 'zenether' ),
		) );

		$defaults = array(
	        'flex-height' => false,
	        'flex-width'  => false,
	        'header-text' => array( 'site-title', 'site-description' ),
	    );
	    add_theme_support( 'custom-logo', $defaults );
	}
endif; // zenether_setup
add_action( 'after_setup_theme', 'zenether_setup' );

if ( ! function_exists( 'zenether_fonts_url' ) ) :
	/**
	 *	Load google font url used in the zenether theme
	 */
	function zenether_fonts_url() {

	    $fonts_url = '';
	 
	    /* Translators: If there are characters in your language that are not
	    * supported by Montserrat, translate this to 'off'. Do not translate
	    * into your own language.
	    */
	    $questrial = _x( 'on', 'Montserrat font: on or off', 'zenether' );

	    if ( 'off' !== $questrial ) {
	        $font_families = array();
	 
	        $font_families[] = 'Montserrat';
	 
	        $query_args = array(
	            'family' => urlencode( implode( '|', $font_families ) ),
	            'subset' => urlencode( 'latin,latin-ext' ),
	        );
	 
	        $fonts_url = add_query_arg( $query_args, '//fonts.googleapis.com/css' );
	    }
	 
	    return $fonts_url;
	}
endif; // zenether_fonts_url

if ( ! function_exists( 'zenether_load_scripts' ) ) :
	/**
	 * the main function to load scripts in the zenether theme
	 * if you add a new load of script, style, etc. you can use that function
	 * instead of adding a new wp_enqueue_scripts action for it.
	 */
	function zenether_load_scripts() {

		// load main stylesheet.
		wp_enqueue_style( 'font-awesome', get_template_directory_uri() . '/css/font-awesome.css', array( ) );
		wp_enqueue_style( 'zenether-style', get_stylesheet_uri(), array() );
		
		wp_enqueue_style( 'zenether-fonts', zenether_fonts_url(), array(), null );
		
		if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
			wp_enqueue_script( 'comment-reply' );
		}

		wp_enqueue_script( 'zenether', get_template_directory_uri() . '/js/zenether.js',
			array( 'jquery', ) );
	}
endif; // zenether_load_scripts
add_action( 'wp_enqueue_scripts', 'zenether_load_scripts' );

if ( ! function_exists( 'zenether_widgets_init' ) ) :
	/**
	 *	widgets-init action handler. Used to register widgets and register widget areas
	 */
	function zenether_widgets_init() {
		
		// Register Sidebar Widget.
		register_sidebar( array (
							'name'	 		 =>	 __( 'Sidebar Widget Area', 'zenether'),
							'id'		 	 =>	 'sidebar-widget-area',
							'description'	 =>  __( 'The sidebar widget area', 'zenether'),
							'before_widget'	 =>  '',
							'after_widget'	 =>  '',
							'before_title'	 =>  '<div class="sidebar-before-title"></div><h3 class="sidebar-title">',
							'after_title'	 =>  '</h3><div class="sidebar-after-title"></div>',
						) );

		// Register Footer Column #1
		register_sidebar( array (
								'name'			 =>  __( 'Footer Column #1', 'zenether' ),
								'id' 			 =>  'footer-column-1-widget-area',
								'description'	 =>  __( 'The Footer Column #1 widget area', 'zenether' ),
								'before_widget'  =>  '',
								'after_widget'	 =>  '',
								'before_title'	 =>  '<h2 class="footer-title">',
								'after_title'	 =>  '</h2><div class="footer-after-title"></div>',
							) );
		
		// Register Footer Column #2
		register_sidebar( array (
								'name'			 =>  __( 'Footer Column #2', 'zenether' ),
								'id' 			 =>  'footer-column-2-widget-area',
								'description'	 =>  __( 'The Footer Column #2 widget area', 'zenether' ),
								'before_widget'  =>  '',
								'after_widget'	 =>  '',
								'before_title'	 =>  '<h2 class="footer-title">',
								'after_title'	 =>  '</h2><div class="footer-after-title"></div>',
							) );
		
		// Register Footer Column #3
		register_sidebar( array (
								'name'			 =>  __( 'Footer Column #3', 'zenether' ),
								'id' 			 =>  'footer-column-3-widget-area',
								'description'	 =>  __( 'The Footer Column #3 widget area', 'zenether' ),
								'before_widget'  =>  '',
								'after_widget'	 =>  '',
								'before_title'	 =>  '<h2 class="footer-title">',
								'after_title'	 =>  '</h2><div class="footer-after-title"></div>',
							) );
	}
endif; // zenether_widgets_init
add_action( 'widgets_init', 'zenether_widgets_init' );

if ( ! function_exists( 'zenether_show_copyright_text' ) ) :
	/**
	 *	Displays the copyright text.
	 */
	function zenether_show_copyright_text() {

		$footerText = get_theme_mod('zenether_footer_copyright', null);

		if ( !empty( $footerText ) ) {

			echo esc_html( $footerText ) . ' | ';		
		}
	}
endif; // zenether_show_copyright_text

if ( ! function_exists( 'zenether_custom_header_setup' ) ) :
	/**
	 * Set up the WordPress core custom header feature.
	 *
	 * @uses zenether_header_style()
	 */
	function zenether_custom_header_setup() {

  		add_theme_support( 'custom-header', array (
                         'default-image'          => '',
                         'flex-height'            => true,
                         'flex-width'             => true,
                         'uploads'                => true,
                         'width'                  => 900,
                         'height'                 => 500,
                         'default-text-color'     => '#434343',
                         'wp-head-callback'       => 'zenether_header_style',
                      ) );
  	}
endif; // zenether_custom_header_setup
add_action( 'after_setup_theme', 'zenether_custom_header_setup' );

if ( ! function_exists( 'zenether_header_style' ) ) :
	/**
	 * Styles the header image and text displayed on the blog.
	 *
	 * @see zenether_custom_header_setup().
	 */
	function zenether_header_style() {

  		$header_text_color = get_header_textcolor();

    	if ( ! has_header_image()
          && ( get_theme_support( 'custom-header', 'default-text-color' ) === $header_text_color
               || 'blank' === $header_text_color ) ) {

          return;
    }
    $headerImage = get_header_image();
?>
      <style id="zenether-custom-header-styles" type="text/css">

          <?php if ( has_header_image() ) : ?>

                  #header-main-fixed {background-image: url("<?php echo esc_url( $headerImage ); ?>");}

          <?php endif; ?>

          <?php if ( get_theme_support( 'custom-header', 'default-text-color' ) !== $header_text_color
                      && 'blank' !== $header_text_color ) : ?>

                  #header-main-fixed, #header-main-fixed h1.entry-title {color: #<?php echo sanitize_hex_color_no_hash( $header_text_color ); ?>;}

          <?php endif; ?>
      </style>
<?php
  }
endif; // End of zenether_header_style.

if ( class_exists('WP_Customize_Section') ) {
	class zenether_Customize_Section_Pro extends WP_Customize_Section {

		// The type of customize section being rendered.
		public $type = 'zenether';

		// Custom button text to output.
		public $pro_text = '';

		// Custom pro button URL.
		public $pro_url = '';

		// Add custom parameters to pass to the JS via JSON.
		public function json() {
			$json = parent::json();

			$json['pro_text'] = $this->pro_text;
			$json['pro_url']  = esc_url( $this->pro_url );

			return $json;
		}

		// Outputs the template
		protected function render_template() {

?>

			<li id="accordion-section-{{ data.id }}" class="accordion-section control-section control-section-{{ data.type }} cannot-expand">

				<h3 class="accordion-section-title">
					{{ data.title }}

					<# if ( data.pro_text && data.pro_url ) { #>
						<a href="{{ data.pro_url }}" class="button button-primary alignright" target="_blank">{{ data.pro_text }}</a>
					<# } #>
				</h3>
			</li>
		<?php }
	}
}

/**
 * Singleton class for handling the theme's customizer integration.
 */
final class zenether_Customize {

	// Returns the instance.
	public static function get_instance() {

		static $instance = null;

		if ( is_null( $instance ) ) {
			$instance = new self;
			$instance->setup_actions();
		}

		return $instance;
	}

	// Constructor method.
	private function __construct() {}

	// Sets up initial actions.
	private function setup_actions() {

		// Register panels, sections, settings, controls, and partials.
		add_action( 'customize_register', array( $this, 'sections' ) );

		// Register scripts and styles for the controls.
		add_action( 'customize_controls_enqueue_scripts', array( $this, 'enqueue_control_scripts' ), 0 );
	}

	// Sets up the customizer sections.
	public function sections( $manager ) {

		// Load custom sections.

		// Register custom section types.
		$manager->register_section_type( 'zenether_Customize_Section_Pro' );

		// Register sections.
		$manager->add_section(
			new zenether_Customize_Section_Pro(
				$manager,
				'zenether',
				array(
					'title'    => esc_html__( 'ZenEtherPro', 'zenether' ),
					'pro_text' => esc_html__( 'Upgrade to Pro', 'zenether' ),
					'pro_url'  => esc_url( 'https://zentemplates.com/product/zenetherpro' )
				)
			)
		);
	}

	// Loads theme customizer CSS.
	public function enqueue_control_scripts() {

		wp_enqueue_script( 'zenether-customize-controls', trailingslashit( get_template_directory_uri() ) . 'js/customize-controls.js', array( 'customize-controls' ) );

		wp_enqueue_style( 'zenether-customize-controls', trailingslashit( get_template_directory_uri() ) . 'css/customize-controls.css' );
	}
}

// Doing this customizer thang!
zenether_Customize::get_instance();

if ( ! function_exists( 'zenether_customize_add_section') ) :

	/**
	 * Add a Customizer Field Setting
	 *
	 * @param WP_Customize_Manager $wp_customize Theme Customizer object
	 * @param String $sectionId the identifier for the Customizer section
	 * @param String $sectionTitle Customizer Section Title
	 */
	function zenether_customize_add_section($wp_customize, $sectionId, $sectionTitle) {

		$wp_customize->add_section(
			$sectionId,
			array(
				'title'       => $sectionTitle,
				'capability'  => 'edit_theme_options',
			)
		);
	}

endif; // zenether_customize_add_section

if ( ! function_exists( 'zenether_customize_add_field') ) :

	/**
	 * Add a Customizer Field Setting
	 *
	 * @param WP_Customize_Manager $wp_customize Theme Customizer object
	 * @param String $id the identifier for the Customizer field
	 * @param String $default default value
	 * @param String $sanitize_callback a function name to call for sanitizing the input value
	 * @param String $label Customizer field label text
	 * @param String $section Theme Customizer object
	 * @param String $type Specifies the TYPE of setting
	 */
	function zenether_customize_add_field($wp_customize, $id, $default,
		$sanitize_callback, $label, $section, $type) {

		$wp_customize->add_setting(
			$id,
			array(
			    'default'           => $default,
			    'sanitize_callback' => $sanitize_callback,
			)
		);

		$wp_customize->add_control( new WP_Customize_Control( $wp_customize, $id,
	        array(
	            'label'          => $label,
	            'section'        => $section,
	            'settings'       => $id,
	            'type'           => $type,
	            )
	        )
		);
	}

endif; // zenether_customize_add_field

/**
 * Sanitization callback for 'url' type text inputs. This callback sanitizes `$url` as a valid URL.
 */
if ( ! function_exists( 'zenether_sanitize_url' ) ) :

	function zenether_sanitize_url( $url ) {
		return esc_url_raw( $url );
	}

endif; // zenether_sanitize_url

if ( ! function_exists( 'zenether_customize_register' ) ) :
	/**
	 * Add postMessage support for site title and description for the Theme Customizer.
	 *
	 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
	 */
	function zenether_customize_register( $wp_customize ) {

		/**
		 * Add Header Image Section Title, Text and URL Customizer Options
		 */
		zenether_customize_add_field( $wp_customize, 'zenether_header_img_ttl', '',
			'sanitize_text_field', __( 'Header Image Section Title', 'zenether' ),
			'header_image', 'text');

		zenether_customize_add_field( $wp_customize, 'zenether_header_img_txt', '',
			'sanitize_text_field', __( 'Header Image Section Text', 'zenether' ),
			'header_image', 'text');

		zenether_customize_add_field( $wp_customize, 'zenether_header_img_linktxt', '',
			'sanitize_text_field', __( 'Header Image Button Text', 'zenether' ),
			'header_image', 'text');

		zenether_customize_add_field( $wp_customize, 'zenether_header_img_link', '',
			'zenether_sanitize_url', __( 'Header Image Button URL', 'zenether' ),
			'header_image', 'text');

		/**
		 * Add Footer Section
		 */
		zenether_customize_add_section($wp_customize, 'zenether_footer_section',
				__( 'Footer', 'zenether' ) );
		
		// Add Footer Copyright Text
		zenether_customize_add_field( $wp_customize, 'zenether_footer_copyright', '',
			'sanitize_text_field', __( 'Copyright Text', 'zenether' ),
			'zenether_footer_copyright', 'text');
	}

endif; // zenether_customize_register
add_action( 'customize_register', 'zenether_customize_register' );

/**
 * Fix skip link focus in IE11.
 *
 * This does not enqueue the script because it is tiny and because it is only for IE11,
 * thus it does not warrant having an entire dedicated blocking script being loaded.
 *
 * @link https://git.io/vWdr2
 */
function zenether_skip_link_focus_fix() {
	// The following is minified via `terser --compress --mangle -- js/skip-link-focus-fix.js`.
	?>
	<script>
	/(trident|msie)/i.test(navigator.userAgent)&&document.getElementById&&window.addEventListener&&window.addEventListener("hashchange",function(){var t,e=location.hash.substring(1);/^[A-z0-9_-]+$/.test(e)&&(t=document.getElementById(e))&&(/^(?:a|select|input|button|textarea)$/i.test(t.tagName)||(t.tabIndex=-1),t.focus())},!1);
	</script>
	<?php
}
add_action( 'wp_print_footer_scripts', 'zenether_skip_link_focus_fix' );
